package tech.mercantec.easyeat.ui.dishes

import android.content.Intent
import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Button
import android.widget.Toast
import androidx.fragment.app.Fragment
import androidx.lifecycle.lifecycleScope
import kotlinx.coroutines.launch
import tech.mercantec.easyeat.R
import tech.mercantec.easyeat.databinding.FragmentDishesBinding
import tech.mercantec.easyeat.helpers.ApiRequestException
import tech.mercantec.easyeat.helpers.RecipeResponse
import tech.mercantec.easyeat.helpers.getRecipies
import tech.mercantec.easyeat.helpers.login
import tech.mercantec.easyeat.models.DishListItem
import tech.mercantec.easyeat.ui.MainActivity
import kotlin.concurrent.thread

class DishesFragment : Fragment() {

    private var _binding: FragmentDishesBinding? = null

    // This property is only valid between onCreateView and
    // onDestroyView.
    private val binding get() = _binding!!

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        _binding = FragmentDishesBinding.inflate(inflater, container, false)
        val root: View = binding.root


        thread {
            val recipes: List<RecipeResponse>
            try {
                recipes = getRecipies(requireContext())
            } catch (e: ApiRequestException) {
                activity?.runOnUiThread {
                    Toast.makeText(requireContext(), e.message, Toast.LENGTH_LONG).show()
                }

                return@thread
            }
            val dishes = recipes.map {
                DishListItem(
                    it.name,
                    it.description
                ) // assuming description is the main ingredient and no price
            }
        }

//        lifecycleScope.launch {
//            try {
//                val recipes = getRecipies(requireContext()) // this is now suspend
//                val dishes = recipes.map {
//                    DishListItem(it.name, it.description) // assuming description is the main ingredient and no price
//                }
//
//                val adapter = DishAdapter(requireContext(), dishes)
//                binding.dishesList.adapter = adapter
//            } catch (e: Exception) {
//                Log.i("nice", e.message.toString())
//                Toast.makeText(requireContext(), "Failed to load recipes: ${e.message}", Toast.LENGTH_LONG).show()
//            }
//        }


        binding.addDish.setOnClickListener {
            val dialogView = LayoutInflater.from(requireContext()).inflate(R.layout.create_dish_modal_dialog, null)

            val dialog = android.app.AlertDialog.Builder(requireContext())
                .setView(dialogView)
                .setCancelable(true) // tap outside to dismiss
                .create()

            dialog.window?.setBackgroundDrawableResource(android.R.color.transparent)

            dialogView.findViewById<Button>(R.id.createManualBtn).setOnClickListener {
                val intent = Intent(requireContext(), CreateDishActivity::class.java)
                startActivity(intent)
                dialog.dismiss()
            }

            dialogView.findViewById<Button>(R.id.createAIBtn).setOnClickListener {
                val intent = Intent(requireContext(), CreateDishAIActivity::class.java)
                startActivity(intent)
                dialog.dismiss()
            }

            dialog.show()
        }


        return root
    }




    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }
}